@@ -196,6 +196,10 @@ class NodeACHandler(ShellHandler):
         include_private = part.startswith('_')
         cls = self.__class__
 
+        # No autocompletion anymore after an action has been typed.
+        if self.attr_name:
+            return
+
         # Current node
         if '.'.startswith(part):
             yield '.', self
@@ -265,7 +269,7 @@ class Version(ShellHandler):
         print termcolor.colored(deployer.__version__, 'red')
         print termcolor.colored('  Host:                      ', 'cyan'),
         print termcolor.colored(socket.gethostname(), 'red')
-        print termcolor.colored('  Root node class:        ', 'cyan'),
+        print termcolor.colored('  Root node class:           ', 'cyan'),
         print termcolor.colored(self.shell.root_node.__module__, 'red'),
         print termcolor.colored('  <%s>' % self.shell.root_node.__class__.__name__, 'red')
 
@@ -532,6 +536,22 @@ class Ls(NodeACHandler):
 
         console.lesspipe(run())
 
+class Pwd(NodeACHandler):
+    """
+    Print current node path.
+    ``pwd``, like "Print working Directory" in the Bash shell.
+    """
+    def __call__(self):
+        result = [ ]
+
+        for node, name in Inspector(self.node).get_path(PathType.NODE_AND_NAME):
+            color = Inspector(node).get_group().color
+            result.append(termcolor.colored(name, color))
+
+        sys.stdout.write(termcolor.colored('/', 'cyan'))
+        sys.stdout.write(termcolor.colored('.', 'cyan').join(result) + '\n')
+        sys.stdout.flush()
+
 
 class SourceCode(NodeACHandler):
     """
@@ -667,6 +687,7 @@ class RootHandler(ShellHandler):
             'find': Find,
             'ls': Ls,
             'sandbox': Sandbox,
+            'pwd': Pwd,
             '--connect': Connect,
             '--inspect': Inspect,
             '--version': Version,
